@@ -1,8 +1,5 @@
 #pragma once
 
-#ifndef FF_INCLUDED_detection_opengl_opengl
-#define FF_INCLUDED_detection_opengl_opengl
-
 #include "fastfetch.h"
 
 typedef struct FFOpenGLResult
@@ -11,8 +8,7 @@ typedef struct FFOpenGLResult
     FFstrbuf renderer;
     FFstrbuf vendor;
     FFstrbuf slv;
+    const char* library;
 } FFOpenGLResult;
 
-const char* ffDetectOpenGL(FFinstance* instance, FFOpenGLResult* result);
-
-#endif
+const char* ffDetectOpenGL(FFOpenGLOptions* options, FFOpenGLResult* result);
